@@ -15,6 +15,12 @@ from dvc.remote.pool import close_pools
 from dvc.utils.compat import is_py2
 
 
+# Workaround for CPython bug. See [1] and [2] for more info.
+# [1] https://github.com/aws/aws-cli/blob/1.16.277/awscli/clidriver.py#L55
+# [2] https://bugs.python.org/issue29288
+"".encode("idna")
+
+
 logger = logging.getLogger("dvc")
 
 
